Author: kristwaa
Date: Tue May 22 21:14:36 2012
New Revision: 1341629
URL: http://svn.apache.org/viewvc?rev=1341629&view=rev
Log:
DERBY-5680: indexStat daemon processing tables over an over even when there are no changes
in the tables
Renamed debug property to a more descriptive name.
Patch file: derby-5680-3a-rename_debug_property.diff
Modified:
db/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/Property.java
db/derby/code/trunk/java/engine/org/apache/derby/impl/services/daemon/IndexStatisticsDaemonImpl.java
db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/KeepDisposableStatsPropertyTest.java
Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/Property.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/Property.java?rev=1341629&r1=1341628&r2=1341629&view=diff
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/Property.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/Property.java Tue May
22 21:14:36 2012
@@ -721,10 +721,10 @@ public interface Property {
int STORAGE_AUTO_INDEX_STATS_DEBUG_QUEUE_SIZE_DEFAULT = 20;
/**
* Specifies whether to force old behavior (pre 10.9) for statistics update.
*/
- String STORAGE_AUTO_INDEX_STATS_DEBUG_FORCE_OLD_BEHAVIOR =
- "derby.storage.indexStats.debug.forceOldBehavior";
+ String STORAGE_AUTO_INDEX_STATS_DEBUG_KEEP_DISPOSABLE_STATS =
+ "derby.storage.indexStats.debug.keepDisposableStats";
/*
** Transactions
Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/services/daemon/IndexStatisticsDaemonImpl.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/services/daemon/IndexStatisticsDaemonImpl.java?rev=1341629&r1=1341628&r2=1341629&view=diff
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/services/daemon/IndexStatisticsDaemonImpl.java
(original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/services/daemon/IndexStatisticsDaemonImpl.java
Tue May 22 21:14:36 2012
@@ -221,7 +221,7 @@ public class IndexStatisticsDaemonImpl
// For now allow users to override the new behavior through a debug
// property. Will be removed or renamed in a future release.
boolean keepDisposableStats = PropertyUtil.getSystemBoolean(
- Property.STORAGE_AUTO_INDEX_STATS_DEBUG_FORCE_OLD_BEHAVIOR);
+ Property.STORAGE_AUTO_INDEX_STATS_DEBUG_KEEP_DISPOSABLE_STATS);
this.skipDisposableStats = dbAtLeast10_9(db) && !keepDisposableStats;
this.db = db;
Modified: db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/KeepDisposableStatsPropertyTest.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/KeepDisposableStatsPropertyTest.java?rev=1341629&r1=1341628&r2=1341629&view=diff
==============================================================================
--- db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/KeepDisposableStatsPropertyTest.java
(original)
+++ db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/KeepDisposableStatsPropertyTest.java
Tue May 22 21:14:36 2012
@@ -147,7 +147,7 @@ public class KeepDisposableStatsProperty
* explicitly setting it to {@code false}.
*/
public static Test suite() {
- String property = "derby.storage.indexStats.debug.forceOldBehavior";
+ String property = "derby.storage.indexStats.debug.keepDisposableStats";
TestSuite suite = new TestSuite("KeepDisposableStatsPropertyTestSuite");
// Test the default (expected to be false).
suite.addTest(
@@ -721,10 +721,10 @@ public interface Property {
int STORAGE_AUTO_INDEX_STATS_DEBUG_QUEUE_SIZE_DEFAULT = 20;
/**
- * Specifies whether to force old behavior (pre 10.9) for statistics update.
+ * Specifies whether to revert to 10.8 behavior and keep disposable stats.
*/
|